import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ArrangeService } from '../../service/dining/arrange.service';
import { CDTO_arrange, CVO_arrange, FVO_arrange, QDTO_arrange, QVO_arrange, UDTO_arrange, UVAO_arrange } from '../../interface/dining/arrange.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['日程安排'])
@Controller('/arrange')
export class ArrangeController extends BaseController {
  @Inject()
  service: ArrangeService;

  @Get('/getByDate')
  @ApiResponse({})
  async getByDate(@Query('date') date: string) {
    const data = await this.service.findOne({ date });
    const result = new FVO_arrange(data);
    return result;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_arrange })
  async create(@Body() data: CDTO_arrange) {
    const dbData = await this.service.create(data);
    const result = new CVO_arrange(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_arrange })
  async query(@Query() filter: QDTO_arrange, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_arrange(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_arrange })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_arrange(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_arrange })
  async update(@Param('id') id: string, @Body() body: UDTO_arrange) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
