import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { MenuService } from '../../service/dining/menu.service';
import { CDTO_menu, CVO_menu, FVO_menu, QDTO_menu, QVO_menu, UDTO_menu, UVAO_menu } from '../../interface/dining/menu.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['菜品'])
@Controller('/menu')
export class MenuController extends BaseController {
  @Inject()
  service: MenuService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_menu })
  async create(@Body() data: CDTO_menu) {
    const dbData = await this.service.create(data);
    const result = new CVO_menu(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_menu })
  async query(@Query() filter: QDTO_menu, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_menu(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_menu })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_menu(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_menu })
  async update(@Param('id') id: string, @Body() body: UDTO_menu) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
