import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { OrderService } from '../../service/dining/order.service';
import { CDTO_order, CVO_order, FVO_order, QDTO_order, QVO_order, UDTO_order, UVAO_order } from '../../interface/dining/order.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['订单'])
@Controller('/order')
export class OrderController extends BaseController {
  @Inject()
  service: OrderService;

  @Get('/computedMeal/:date')
  async computedMeal(@Param('date') date:string){
    const result = await this.service.computedMeal(date)
    return result;
  }

  @Get('/useMeal/:id')
  async useMeal(@Param('id') id: string) {
    await this.service.useMeal(id)
    return 'ok';
  }

  @Post('/mealCard/:openid')
  async mealCard(@Param('openid') openid: string) {
    const data = await this.service.mealCard(openid);
    const result = new FVO_order(data);
    return result;
  }

  @Get('/getByOpenid')
  async getByOpenid(@Query('openid') openid: string, @Query('date') date: string) {
    const data = await this.service.findOne({ openid, date });
    const result = new FVO_order(data);
    return result;
  }

  @Get('/getMeal/:id')
  async getMeal(@Param('id') id: string) {
    const data = await this.service.getMeal(id);
    const result = new FVO_order(data);
    return result;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_order })
  async create(@Body() data: CDTO_order) {
    const dbData = await this.service.create(data);
    const result = new CVO_order(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_order })
  async query(@Query() filter: QDTO_order, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_order(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_order })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_order(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_order })
  async update(@Param('id') id: string, @Body() body: UDTO_order) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
