import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { RateService } from '../../service/dining/rate.service';
import { CDTO_rate, CVO_rate, FVO_rate, QDTO_rate, QVO_rate, UDTO_rate, UVAO_rate } from '../../interface/dining/rate.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['菜品评价'])
@Controller('/rate')
export class RateController extends BaseController {
  @Inject()
  service: RateService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_rate })
  async create(@Body() data: CDTO_rate) {
    const dbData = await this.service.create(data);
    const result = new CVO_rate(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_rate })
  async query(@Query() filter: QDTO_rate, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_rate(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_rate })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_rate(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_rate })
  async update(@Param('id') id: string, @Body() body: UDTO_rate) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
