import { Rule, RuleType } from '@midwayjs/validate';
import { ApiProperty } from '@midwayjs/swagger';
import { FrameworkErrorEnum, SearchBase, ServiceError } from 'free-midway-component';
import get = require('lodash/get');
const dealVO = (cla, data) => {
  for (const key in cla) {
    const val = get(data, key);
    if (val || val === 0) cla[key] = val;
  }
};
export class FVO_rate {
  constructor(data: object) {
    dealVO(this, data);
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: '菜品id' })
  'menu_id': string = undefined;
  @ApiProperty({ description: '用户id' })
  'openid': string = undefined;
  @ApiProperty({ description: '评价分数' })
  'score': number = undefined;
  @ApiProperty({ description: '评价内容' })
  'content': string = undefined;
}

export class QDTO_rate extends SearchBase {
  constructor() {
    const like_prop = [];
    const props = ['menu_id'];
    const mapping = [];
    super({ like_prop, props, mapping });
  }
  @ApiProperty({ description: '菜品id' })
  'menu_id': string = undefined;
}

export class QVO_rate extends FVO_rate {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class CDTO_rate {
  @ApiProperty({ description: '菜品id' })
  @Rule(RuleType['string']().required().error(new ServiceError('缺少菜品id', FrameworkErrorEnum.NEED_BODY)))
  'menu_id': string = undefined;
  @ApiProperty({ description: '用户id' })
  @Rule(RuleType['string']().required().error(new ServiceError('缺少用户id', FrameworkErrorEnum.NEED_BODY)))
  'openid': string = undefined;
  @ApiProperty({ description: '评价分数' })
  @Rule(RuleType['number']().empty(''))
  'score': number = undefined;
  @ApiProperty({ description: '评价内容' })
  @Rule(RuleType['string']().empty(''))
  'content': string = undefined;
}

export class CVO_rate extends FVO_rate {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class UDTO_rate extends CDTO_rate {
  @ApiProperty({ description: '数据id' })
  @Rule(RuleType['string']().empty(''))
  _id: string = undefined;
}

export class UVAO_rate extends FVO_rate {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}
