import { Provide, Inject } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService, ServiceError, FrameworkErrorEnum } from 'free-midway-component';
import { Role } from '../../entity/system/role.entity';
import { Menus } from '../../entity/system/menus.entity';
import { MenusService } from './menus.service';
import flattenDeep = require('lodash/flattenDeep');
import uniq = require('lodash/uniq');
import get = require('lodash/get');
import { Context } from '@midwayjs/koa';
type modelType = ReturnModelType<typeof Role>;
@Provide()
export class RoleService extends BaseService<modelType> {
  @InjectEntityModel(Role)
  model: modelType;
  @InjectEntityModel(Menus)
  menusModel: ReturnModelType<typeof Menus>;

  @Inject()
  menusService: MenusService;
  @Inject()
  ctx: Context;

  async getUserMenus() {
    const user = this.ctx.user;
    // TODO:这里需要改下. 平台的超级管理员有这些权限
    if (user.role === 'Admin' && user.is_super === '0') return await this.menusService.queryMenu();
    const role = await this.model.findOne({ code: user.role, is_use: '0' }).lean();
    if (!role) throw new ServiceError('当前角色下的用户无法使用!', FrameworkErrorEnum.SERVICE_FAULT);
    const menu = get(role, 'menu', {});
    const mode = get(menu, 'mode');
    if (mode !== 'select') return await this.menusService.queryMenu();
    let routerPaths = Object.keys(menu);
    routerPaths = routerPaths.filter(f => f !== 'mode');
    const pageMenus = await this.menusModel.find({ path: routerPaths, is_use: '0' }, { _id: 1, parent_id: 1 }, { sort: { order_num: 1 } }).lean();
    const menuIds = pageMenus.map(i => i._id);
    let parentIds = pageMenus.filter(i => i.parent_id);
    while (parentIds.length > 0) {
      const mid = await this.menusModel.find({ _id: parentIds, is_use: '0' }, { _id: 1, parent_id: 1 }).lean();
      if (mid.length <= 0) break;
      menuIds.push(mid.map(i => i._id));
      parentIds = mid.filter(i => i.parent_id);
    }
    const rmenus = await this.menusModel.find({ _id: menuIds, is_use: '0' }, {}, { sort: { order_num: 1 } }).lean();
    let treeMenu = rmenus.filter(f => !f.parent_id);
    treeMenu = this.menusService.treeMenu(rmenus, treeMenu);
    return treeMenu;
  }

  /**
   * 根据角色id数组,整理菜单
   * @param roleIdList 角色id数组
   */
  async getMenuByRoles(roleIdList) {
    let menus = [];
    // 第一步,整理所有菜单至一维数组
    for (const r of roleIdList) {
      menus.push(...flattenDeep(r));
    }
    menus = uniq(menus);
    const allMenu = await this.menusModel.find({ _id: menus, is_use: '0' }, { meta: 0, __v: 0 }).sort({ order_num: 1 }).lean();
    let treeMenu = allMenu.filter(f => !f.parent_id);
    treeMenu = this.menusService.treeMenu(allMenu, treeMenu);
    return treeMenu;
  }
}
