import { Config, Provide } from '@midwayjs/decorator';
import { Inject, makeHttpRequest } from '@midwayjs/core';
import get = require('lodash/get');
import { FrameworkErrorEnum, ServiceError } from 'free-midway-component';
import { Context } from '@midwayjs/koa';
import * as CryptoJs from 'crypto-js';
import { UserService } from './system/user.service';
import { AdminService } from './system/admin.service';

@Provide()
export class WeixinService {
  @Config('weixinConfig')
  weixinConfig;
  @Inject()
  ctx: Context;
  @Inject()
  userService: UserService;
  @Inject()
  adminService: AdminService;

  async appAuth() {
    const query = this.ctx.query;
    const js_code = get(query, 'js_code');
    const { appid, secret } = this.weixinConfig;
    const url = `https://api.weixin.qq.com/sns/jscode2session?appid=${appid}&secret=${secret}&js_code=${js_code}&grant_type=authorization_code`;
    const result = await makeHttpRequest(url, {
      dataType: 'json',
      headers: {
        'content-type': 'application/json',
      },
    });
    const openid = get(result, 'data.openid');
    if (!openid) throw new ServiceError('未获取到openid', FrameworkErrorEnum.REQUEST_FAULT);
    let user = await this.userService.findOne({ openid });
    if (!user) user = await this.userService.create({ openid });
    const admin = await this.adminService.findOne({ openid });
    if (admin) Object.assign({ is_admin: true }, user);
    return user;
  }

  //TODO:
  async getSecret() {
    const body = this.ctx.request.body;
    const encryptedData = get(body, 'encryptedData');
    const iv = get(body, 'iv');
    const session_key = get(body, 'session_key');
    if (!encryptedData || !iv || !session_key) throw new ServiceError('参数错误', FrameworkErrorEnum.BAD_PARAMS);
    // const base64_sk = Buffer.from(session_key, 'base64').toString();
    // const base64_e = Buffer.from(encryptedData, 'base64').toString();
    // const base64_iv = Buffer.from(iv, 'base64');
    const base64_sk = CryptoJs.enc.Base64.parse(session_key);
    // const base64_e = CryptoJs.enc.Base64.parse(encryptedData);
    const base64_iv = CryptoJs.enc.Base64.parse(iv);
    let decoded;
    try {
      decoded = CryptoJs.AES.decrypt(encryptedData, base64_sk, { iv: base64_iv });
      // const decipher = CryptoJs.createDecipheriv('aes-128-cbc', session_key, iv);
      return decoded;
    } catch (e) {
      console.error(e);
      throw new ServiceError('解密失败', FrameworkErrorEnum.SERVICE_FAULT);
    }
  }
}
